"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.collaboratorsManager = void 0;
const lodash_1 = __importDefault(require("lodash"));
const sequelize_1 = require("sequelize");
const collaborators_1 = require("../../models/collaborators");
const users_1 = require("../../models/users");
const app_error_1 = require("../app-error");
class CollaboratorsManager {
    listCollaborators(appId) {
        return collaborators_1.Collaborators.findAll({ where: { appid: appId } })
            .then((data) => {
            return lodash_1.default.reduce(data, (result, value) => {
                result.uids.push(value.uid);
                result.colByUid[value.uid] = value;
                return result;
            }, {
                uids: [],
                colByUid: {},
            });
        })
            .then((coInfo) => {
            return users_1.Users.findAll({ where: { id: { [sequelize_1.Op.in]: coInfo.uids } } }).then((data2) => {
                return lodash_1.default.reduce(data2, (result, value) => {
                    let permission = '';
                    if (!lodash_1.default.isEmpty(coInfo.colByUid[value.id])) {
                        permission = coInfo.colByUid[value.id].roles;
                    }
                    result[value.email] = { permission };
                    return result;
                }, {});
            });
        });
    }
    addCollaborator(appId, uid) {
        return collaborators_1.Collaborators.findOne({ where: { appid: appId, uid } }).then((data) => {
            if (lodash_1.default.isEmpty(data)) {
                return collaborators_1.Collaborators.create({
                    appid: appId,
                    uid,
                    roles: 'Collaborator',
                });
            }
            throw new app_error_1.AppError('user already is Collaborator.');
        });
    }
    deleteCollaborator(appId, uid) {
        return collaborators_1.Collaborators.findOne({ where: { appid: appId, uid } }).then((data) => {
            if (lodash_1.default.isEmpty(data)) {
                throw new app_error_1.AppError('user is not a Collaborator');
            }
            else {
                return collaborators_1.Collaborators.destroy({ where: { id: data.id } });
            }
        });
    }
}
exports.collaboratorsManager = new CollaboratorsManager();
