"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.emailManager = void 0;
const lodash_1 = __importDefault(require("lodash"));
const nodemailer_1 = __importDefault(require("nodemailer"));
const app_error_1 = require("../app-error");
const config_1 = require("../config");
class EmailManager {
    sendMail(options) {
        return new Promise((resolve, reject) => {
            if (!lodash_1.default.get(options, 'to')) {
                reject(new app_error_1.AppError('to是必传参数'));
                return;
            }
            const { smtpConfig } = config_1.config;
            if (!smtpConfig || !smtpConfig.host) {
                resolve({});
                return;
            }
            const transporter = nodemailer_1.default.createTransport(smtpConfig);
            const sendEmailAddress = smtpConfig.auth.user;
            const defaultMailOptions = {
                from: `"CodePush Server" <${sendEmailAddress}>`,
                to: '',
                subject: 'CodePush Server',
                html: '', // html body
            };
            const mailOptions = lodash_1.default.assign(defaultMailOptions, options);
            transporter.sendMail(mailOptions, (error, info) => {
                if (error) {
                    reject(error);
                    return;
                }
                resolve(info);
            });
        });
    }
    sendRegisterCodeMail(email, code) {
        return this.sendMail({
            to: email,
            html: `<div>您接收的验证码为: <em style="color:red;">${code}</em>  20分钟内有效</div>`,
        });
    }
}
exports.emailManager = new EmailManager();
