#!/usr/bin/env node
"use strict";
/* eslint-disable no-console */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Module dependencies.
 */
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const lodash_1 = __importDefault(require("lodash"));
const mysql2_1 = __importDefault(require("mysql2"));
const yargs_1 = __importDefault(require("yargs"));
const const_1 = require("./core/const");
const argv = yargs_1.default
    .usage('Usage: $0 <command> [options]')
    .command('init', '初始化数据库', {
    dbpassword: {
        alias: 'dbpassword',
        type: 'string',
    },
})
    .command('upgrade', '升级数据库', {
    dbpassword: {
        alias: 'dbpassword',
        type: 'string',
    },
})
    .example('$0 init --dbname codepush --dbhost localhost --dbuser root --dbpassword 12345678 --dbport 3306 --force', '初始化code-push-server数据库')
    .example('$0 upgrade --dbname codepush --dbhost localhost --dbuser root --dbpassword 12345678 --dbport 3306', '升级code-push-server数据库')
    .default({
    dbname: 'codepush',
    dbhost: 'localhost',
    dbuser: 'root',
    dbpassword: '12345678',
})
    .help('h')
    .alias('h', 'help')
    .parseSync();
const command = argv._[0];
const dbname = argv.dbname ? argv.dbname : 'codepush';
const dbhost = argv.dbhost ? argv.dbhost : 'localhost';
const dbuser = argv.dbuser ? argv.dbuser : 'root';
const dbport = argv.dbport ? argv.dbport : 3306;
const { dbpassword } = argv;
if (command === 'init') {
    let connection2;
    const connection = mysql2_1.default
        .createConnection({
        host: dbhost,
        user: dbuser,
        password: dbpassword,
        port: dbport,
    })
        .promise();
    const createDatabaseSql = argv.force
        ? `CREATE DATABASE IF NOT EXISTS ${dbname}`
        : `CREATE DATABASE ${dbname}`;
    connection.connect();
    connection
        .query(createDatabaseSql)
        .then(() => {
        connection2 = mysql2_1.default
            .createConnection({
            host: dbhost,
            user: dbuser,
            password: dbpassword,
            database: dbname,
            multipleStatements: true,
            port: dbport,
        })
            .promise();
        connection2.connect();
        return connection2;
    })
        .then(() => {
        const sql = fs_1.default.readFileSync(path_1.default.resolve(__dirname, '../sql/codepush-all.sql'), 'utf-8');
        return connection2.query(sql);
    })
        .then(() => {
        console.log('success.');
    })
        .catch((e) => {
        console.log(e);
    })
        .finally(() => {
        if (connection)
            connection.end();
        if (connection2)
            connection2.end();
    });
}
else if (command === 'upgrade') {
    let connection;
    try {
        connection = mysql2_1.default
            .createConnection({
            host: dbhost,
            user: dbuser,
            password: dbpassword,
            database: dbname,
            multipleStatements: true,
            port: dbport,
        })
            .promise();
        connection.connect();
    }
    catch (e) {
        console.error('connect mysql error, check params', e);
        process.exit(1);
    }
    let versionNo = '0.0.1';
    connection
        .query('select `version` from `versions` where `type`=1 limit 1')
        .then((rs) => {
        versionNo = lodash_1.default.get(rs, '0.version', '0.0.1');
        if (versionNo === const_1.CURRENT_DB_VERSION) {
            console.log('Everything up-to-date.');
            process.exit(0);
        }
        const allSqlFile = [
            {
                version: '0.2.14',
                path: path_1.default.resolve(__dirname, '../sql/codepush-v0.2.14-patch.sql'),
            },
            {
                version: '0.2.15',
                path: path_1.default.resolve(__dirname, '../sql/codepush-v0.2.15-patch.sql'),
            },
            {
                version: '0.3.0',
                path: path_1.default.resolve(__dirname, '../sql/codepush-v0.3.0-patch.sql'),
            },
            {
                version: '0.4.0',
                path: path_1.default.resolve(__dirname, '../sql/codepush-v0.4.0-patch.sql'),
            },
            {
                version: '0.5.0',
                path: path_1.default.resolve(__dirname, '../sql/codepush-v0.5.0-patch.sql'),
            },
        ];
        return allSqlFile.reduce((prev, sqlFile) => {
            if (!lodash_1.default.gt(sqlFile.version, versionNo)) {
                return prev;
            }
            const sql = fs_1.default.readFileSync(sqlFile.path, 'utf-8');
            console.log(`exec sql file:${sqlFile.path}`);
            return connection.query(sql).then(() => {
                console.log(`success exec sql file:${sqlFile.path}`);
            });
        }, Promise.resolve());
    })
        .then(() => {
        console.log('Upgrade success.');
    })
        .catch((e) => {
        console.error(e);
    })
        .finally(() => {
        if (connection)
            connection.end();
    });
}
else {
    yargs_1.default.showHelp();
}
