"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.indexRouter = void 0;
const express_1 = __importDefault(require("express"));
const app_error_1 = require("../core/app-error");
const i18n_1 = require("../core/i18n");
const middleware_1 = require("../core/middleware");
const client_manager_1 = require("../core/services/client-manager");
exports.indexRouter = express_1.default.Router();
exports.indexRouter.get('/', (req, res) => {
    res.render('index', { title: 'CodePushServer' });
});
exports.indexRouter.get('/tokens', (req, res) => {
    // eslint-disable-next-line no-underscore-dangle
    res.render('tokens', { title: `${i18n_1.i18n.__('Obtain')} token` });
});
exports.indexRouter.get('/updateCheck', (req, res, next) => {
    const { logger, query } = req;
    logger.info('updateCheck', {
        query: JSON.stringify(query),
    });
    const { deploymentKey, appVersion, label, packageHash, clientUniqueId } = query;
    client_manager_1.clientManager
        .updateCheckFromCache(deploymentKey, appVersion, label, packageHash, clientUniqueId, logger)
        .then((rs) => {
        // 灰度检测
        return client_manager_1.clientManager
            .chosenMan(rs.packageId, rs.rollout, clientUniqueId)
            .then((data) => {
            if (!data) {
                rs.isAvailable = false;
                return rs;
            }
            return rs;
        });
    })
        .then((rs) => {
        logger.info('updateCheck success');
        delete rs.packageId;
        delete rs.rollout;
        res.send({ updateInfo: rs });
    })
        .catch((e) => {
        if (e instanceof app_error_1.AppError) {
            logger.info('updateCheck failed', {
                error: e.message,
            });
            res.status(404).send(e.message);
        }
        else {
            next(e);
        }
    });
});
exports.indexRouter.post('/reportStatus/download', (req, res) => {
    const { logger, body } = req;
    logger.info('reportStatus/download', {
        body: JSON.stringify(body),
    });
    const { clientUniqueId, label, deploymentKey } = body;
    client_manager_1.clientManager.reportStatusDownload(deploymentKey, label, clientUniqueId).catch((err) => {
        if (err instanceof app_error_1.AppError) {
            logger.info('reportStatus/deploy failed', {
                error: err.message,
            });
        }
        else {
            logger.error(err);
        }
    });
    res.send('OK');
});
exports.indexRouter.post('/reportStatus/deploy', (req, res) => {
    const { logger, body } = req;
    logger.info('reportStatus/deploy', {
        body: JSON.stringify(body),
    });
    const { clientUniqueId, label, deploymentKey } = body;
    client_manager_1.clientManager
        .reportStatusDeploy(deploymentKey, label, clientUniqueId, req.body)
        .catch((err) => {
        if (err instanceof app_error_1.AppError) {
            logger.info('reportStatus/deploy failed', {
                error: err.message,
            });
        }
        else {
            logger.error(err);
        }
    });
    res.send('OK');
});
exports.indexRouter.get('/authenticated', middleware_1.checkToken, (req, res) => {
    return res.send({ authenticated: true });
});
