#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const http_1 = __importDefault(require("http"));
const kv_logger_1 = require("kv-logger");
const lodash_1 = __importDefault(require("lodash"));
const validator_1 = __importDefault(require("validator"));
const app_1 = require("./app");
const const_1 = require("./core/const");
const versions_1 = require("./models/versions");
/**
 * Normalize a port into a number, string, or false.
 */
function normalizePort(val) {
    const port = parseInt(val, 10);
    if (Number.isNaN(port)) {
        // named pipe
        return val;
    }
    if (port >= 0) {
        // port number
        return port;
    }
    return false;
}
// check if the db is initialized
versions_1.Versions.findOne({ where: { type: 1 } })
    .then((v) => {
    if (!v || v.version !== const_1.CURRENT_DB_VERSION) {
        throw new Error('Please upgrade your database. use `npm run upgrade` or `code-push-server-db upgrade`');
    }
    // create server and listen
    const server = http_1.default.createServer(app_1.app);
    const port = normalizePort(process.env.PORT || '3000');
    let host = null;
    if (process.env.HOST) {
        kv_logger_1.logger.debug(`process.env.HOST ${process.env.HOST}`);
        if (validator_1.default.isIP(process.env.HOST)) {
            kv_logger_1.logger.debug(`${process.env.HOST} valid`);
            host = process.env.HOST;
        }
        else {
            kv_logger_1.logger.warn(`process.env.HOST ${process.env.HOST} is invalid, use 0.0.0.0 instead`);
        }
    }
    server.listen(port, host);
    server.on('error', (error) => {
        if (error.syscall === 'listen') {
            const bind = typeof port === 'string' ? `Pipe ${port}` : `Port ${port}`;
            // handle specific listen errors with friendly messages
            switch (error.code) {
                case 'EACCES':
                    kv_logger_1.logger.error(`${bind} requires elevated privileges`);
                    process.exit(1);
                    break;
                case 'EADDRINUSE':
                    kv_logger_1.logger.error(`${bind} is already in use`);
                    process.exit(1);
                    break;
                default:
                    break;
            }
        }
        kv_logger_1.logger.error(error);
        throw error;
    });
    server.on('listening', () => {
        const addr = server.address();
        kv_logger_1.logger.info(`server is listening on ${JSON.stringify(addr)}`);
    });
})
    .catch((e) => {
    if (lodash_1.default.startsWith(e.message, 'ER_NO_SUCH_TABLE')) {
        kv_logger_1.logger.error(new Error('Please upgrade your database. use `npm run upgrade` or `code-push-server-db upgrade`'));
    }
    else {
        kv_logger_1.logger.error(e);
    }
    process.exit(1);
});
